# Ajoute la méthode titleize pour revoir certains formats de noms.
#
module Namesplit
  # Public : Transforme en titre un string.
  #
  def self.titleize(target)
    # Tous les mots sont traités un à un en découpant la phrase à partir des
    # espaces.
    words = target.to_s.split(" ").map do |word|
      # Les apostrophes internes et les tirets sont gérés correctement
      word.split("-").map! do |sub_word|
        sub_word.split("'").map! do |subsub_word|
          titleize_word(subsub_word)
        end.join("'")
      end.join("-")
    end

    words.join(" ")
  end

  private

  # Private : Transforme un mot en minuscule et ajoute une majuscule à la
  # première lettre.
  #
  # Exemple :
  #   "BOÎTE".titleize => "Boîte"
  #
  def self.titleize_word(word)
    accents = { "É" => "é", "È" => "è", "Ê" => "ê", "Ë" => "ë", "À" => "à", "Â" => "â", "Ï" => "ï", "Î" => "î", "Ô" => "ô", "Ù" => "ù", "Û" => "û", "Ü" => "ü", "Ç" => "ç", "Ö" => "ö", "Ÿ" => "ÿ" }

    final = []
    word.chars.each.with_index do |char, index|
      if index == 0
        final << char.upcase
      else
        new_char = accents.values_at(char).first

        if new_char.nil?
          final << char.downcase
        else
          final << new_char
        end
      end
    end

    final.join("")
  end
end
